X402.Behaviour (X402 v0.3.3)

Copy Markdown View Source

Utilities for working with Elixir behaviours and callback implementations.

Summary

Functions

Checks if a module implements a set of callbacks.

Functions

implements?(module, callbacks)

(since 0.1.0)
@spec implements?(module(), [{atom(), integer()}]) :: boolean()

Checks if a module implements a set of callbacks.

The callbacks argument should be a list of {name, arity} tuples.