Behaviour for SIWX signature verification.
Implementations verify a SIWX message signature and return whether the signature matches the claimed wallet address.
Summary
Types
Verifier return value.
Callbacks
Verifies a signature against a message and claimed wallet address.
Functions
Validates that a value is a module implementing X402.Extensions.SIWX.Verifier.
Types
Callbacks
@callback verify_signature( message :: String.t(), signature :: String.t(), address :: String.t() ) :: verify_result()
Verifies a signature against a message and claimed wallet address.
Functions
Validates that a value is a module implementing X402.Extensions.SIWX.Verifier.
This function is intended for NimbleOptions custom validation.